//
//  CustomContactsSettingsView.m
//  SDKTestApp
//
//  Created by Vidyalaxmi V Shenoy on 27/08/15.
//  Copyright (c) 2015 Robosoft. All rights reserved.
//

#import "CustomContactsSettingsView.h"
#import <TeamchatSDK/TeamchatSDK.h>

typedef NS_OPTIONS(NSInteger, ContactOptionButtonType)
{
    ContactOptionButtonTypeLocalContacts = 1,
    ContactOptionButtonTypeTeamchatContacts,
    ContactOptionButtonTypeCustomContacts
};

@interface CustomContactsSettingsView ()

@property (strong, nonatomic) IBOutletCollection(UIButton) NSArray *contactOptionButtons;
@property (strong, nonatomic) IBOutletCollection(UIImageView) NSArray *contactOptionSelectionImageViews;

@end

static NSString *kSelectedImage = @"checkBoxMarked";
static NSString *kDeselectedImage = @"checkBoxEmpty";

@implementation CustomContactsSettingsView

- (void)awakeFromNib
{    
    for (UIButton *optionButton in self.contactOptionButtons)
    {
        switch (optionButton.tag)
        {
            case ContactOptionButtonTypeLocalContacts:
                if ([Teamchat showContactOptions] & TCShowContactFromLocalAddressBook)
                {
                    [self setSelectionImageForImageView:self.contactOptionSelectionImageViews[optionButton.tag - 1] isSelected:YES];
                }
                break;
                
            case ContactOptionButtonTypeTeamchatContacts:
                if ([Teamchat showContactOptions] & TCShowContactFromServerAddressBook)
                {
                    [self setSelectionImageForImageView:self.contactOptionSelectionImageViews[optionButton.tag - 1] isSelected:YES];
                }
                break;
                
            case ContactOptionButtonTypeCustomContacts:
                if ([Teamchat showContactOptions] & TCShowContactFromCustomAddressBook)
                {
                    [self setSelectionImageForImageView:self.contactOptionSelectionImageViews[optionButton.tag - 1] isSelected:YES];
                }
                break;
                
            default:
                break;
        }
    }
}

- (void)setSelectionImageForImageView:(UIImageView *)optionSelectionImageView isSelected:(BOOL)isSelected
{
    NSString *imageName = isSelected ? kSelectedImage : kDeselectedImage;
    optionSelectionImageView.image = [UIImage imageNamed:imageName];
}

- (IBAction)doneButtonTapped:(id)sender
{
    if ([self.settingsDelegate respondsToSelector:@selector(doneButtonTappedFromcustomContactsSettingsView:)])
    {
        [self.settingsDelegate doneButtonTappedFromcustomContactsSettingsView:self];
    }
}


- (IBAction)contactOptionButtonTapped:(UIButton *)optionButton
{
    NSInteger showContactOption = [Teamchat showContactOptions];
    NSInteger tappedOption;
    
    switch (optionButton.tag)
    {
        case ContactOptionButtonTypeLocalContacts:
            tappedOption = TCShowContactFromLocalAddressBook;
            break;
            
        case ContactOptionButtonTypeTeamchatContacts:
            tappedOption = TCShowContactFromServerAddressBook;
            break;
            
        case ContactOptionButtonTypeCustomContacts:
            tappedOption = TCShowContactFromCustomAddressBook;
            break;
            
        default:
            break;
    }
    
    BOOL isOptionSelected = showContactOption & tappedOption;
    
    if (isOptionSelected)
    {
        // Remove tapped option
        showContactOption ^= tappedOption;
    }
    else
    {
        // Add tapped option
        showContactOption |= tappedOption;
    }
    
    [self setSelectionImageForImageView:self.contactOptionSelectionImageViews[optionButton.tag - 1] isSelected:!isOptionSelected];

    [Teamchat setShowContactOptions:showContactOption];
}

@end
